@@ -7,8 +7,7 @@ from axial_positional_embedding import AxialPositionalEmbedding
 from einops import rearrange
 
 from dalle_pytorch import distributed_utils
-from dalle_pytorch.vae import OpenAIDiscreteVAE
-from dalle_pytorch.vae import VQGanVAE1024
+from dalle_pytorch.vae import OpenAIDiscreteVAE, VQGanVAE
 from dalle_pytorch.transformer import Transformer, DivideMax
 
 # helpers
@@ -325,7 +324,7 @@ class DALLE(nn.Module):
         stable = False
     ):
         super().__init__()
-        assert isinstance(vae, (DiscreteVAE, OpenAIDiscreteVAE, VQGanVAE1024)), 'vae must be an instance of DiscreteVAE'
+        assert isinstance(vae, (DiscreteVAE, OpenAIDiscreteVAE, VQGanVAE)), 'vae must be an instance of DiscreteVAE'
 
         image_size = vae.image_size
         num_image_tokens = vae.num_tokens
@@ -370,8 +369,12 @@ class DALLE(nn.Module):
             stable = stable
         )
 
+        self.stable = stable
+
+        if stable:
+            self.norm_by_max = DivideMax(dim = -1)
+
         self.to_logits = nn.Sequential(
-            DivideMax(dim = -1) if stable else nn.Identity(),
             nn.LayerNorm(dim),
             nn.Linear(dim, self.total_tokens),
         )
@@ -498,6 +501,10 @@ class DALLE(nn.Module):
             tokens = tokens[:, :-1]
 
         out = self.transformer(tokens)
+
+        if self.stable:
+            out = self.norm_by_max(out)
+
         logits = self.to_logits(out)
 
         # mask logits to make sure text predicts text (except last token), and image predicts image
