@@ -153,7 +153,9 @@ class VQGanVAE(nn.Module):
 
         self.model = model
 
-        self.num_layers = int(log(config.model.params.ddconfig.attn_resolutions[0])/log(2))
+        # f as used in https://github.com/CompVis/taming-transformers#overview-of-pretrained-models
+        f = config.model.params.ddconfig.resolution / config.model.params.ddconfig.attn_resolutions[0]
+        self.num_layers = int(log(f)/log(2))
         self.image_size = 256
         self.num_tokens = config.model.params.n_embed
 
